@@ -5,7 +5,8 @@ from compiler import compile, visitor
 
 def main():
     VERBOSE = 0
-    opts, args = getopt.getopt(sys.argv[1:], 'vq')
+    DISPLAY = 0
+    opts, args = getopt.getopt(sys.argv[1:], 'vqd')
     for k, v in opts:
         if k == '-v':
             VERBOSE = 1
@@ -16,13 +17,15 @@ def main():
             else:
                 f = open('/dev/null', 'wb')
             sys.stdout = f
+        if k == '-d':
+            DISPLAY = 1
     if not args:
         print "no files to compile"
     else:
         for filename in args:
             if VERBOSE:
                 print filename
-            compile(filename)
+            compile(filename, DISPLAY)
 
 if __name__ == "__main__":
     main()
